@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <sys/time.h>
 #include <unistd.h>
+#include <pthread.h>
 
 #define MODE_IDLE 0
 #define MODE_PLAY_SONG 1
@@ -32,15 +33,27 @@
 #define DEFAULT_TEMPO 130
 
 struct editor {
+  /* MIDI device stream pointer */
   FILE *midi;
+  /* The song currently being edited */
   struct song *song;
+  /* Current location in song */
   unsigned short section, playseq, playseqpos, block;
+  /* Editor modes */
   unsigned char octave, instrument, edit, space, mode;
+  /* Status of tracks; notes playing */
   char *trackstatus;
+  /* For measuring how long the song has been playing */
   struct timeval playingstarted, playedsofar;
+  /* The initialization status of the player thread */
+  int threadstatus;
+  /* Player thread pointer */
+  pthread_t thread;
 };
 
+/* Initializes the editor and either opens an existing song or creates new */
 void editor_open(char *);
+/* Deinitializes the editor */
 void editor_close();
 
 #endif
