@@ -56,21 +56,39 @@ struct song {
   unsigned char mastervolume;
 };
 
+/* Allocates a new song structure and initializes it to default values */
 struct song *song_alloc(void);
+/* Frees a song structure and its contents */
 void song_free(struct song *);
+/* Inserts a new block in the block array in the given position */
 void song_insert_block(struct song *, int);
+/* Deletes a block from the given position of the block array */
 void song_delete_block(struct song *, int);
+/* Inserts a new playseq in the playseq array in the given position */
 void song_insert_playseq(struct song *, int);
+/* Deletes a playseq from the given position of the playseq array */
 void song_delete_playseq(struct song *, int);
+/* Inserts a new section in the section array in the given position */
 void song_insert_section(struct song *, int);
+/* Deletes a section from the given position of the section array */
 void song_delete_section(struct song *, int);
+/* Sets a section in the given position to point somewhere */
 void song_set_section(struct song *, int, int);
+/* Sets the number of ticks per line for a song */
 void song_set_tpl(struct song *, unsigned char);
+/* Sets the tempo of a song */
 void song_set_tempo(struct song *, unsigned char);
+/* If the maximum number of tracks has changed recreate the track volumes */
 int song_check_maxtracks(struct song *);
+/* Make sure the instrument exists; add instruments if necessary */
+void song_check_instrument(struct song *, int);
+/* Converts an MMD2 module to a song */
 struct song *song_convert_MMD2(struct MMD2 *);
+/* Loads a song from an XML file */
 struct song *song_load(char *);
+/* Parses a song element in an XML file */
 struct song *song_parse(xmlDocPtr, xmlNsPtr, xmlNodePtr);
+/* Saves a song to an XML file */
 void song_save(struct song *, char *);
 
 #endif
