@@ -233,7 +233,7 @@ void gui_create() {
   w4=gtk_menu_item_new_with_label("Kill ALL notes");
   gtk_menu_append(GTK_MENU(w3), w4);
   gtk_signal_connect(GTK_OBJECT(w4), "activate",
-		     GTK_SIGNAL_FUNC(stop_all_notes), NULL);
+		     GTK_SIGNAL_FUNC(player_stop_all_notes), NULL);
 
   /* Top horizontal box */
   tophbox=gtk_hbox_new(FALSE, 4);
@@ -1031,7 +1031,7 @@ void gui_sectionlist_select_row(GtkWidget *list, gint row, gint column,
   char playseq[17+8];
 
   editor.section=row;
-  refresh_playseq_and_block();
+  player_refresh_playseq_and_block();
 
   snprintf(section, 8+8, "Section %d/%d", editor.section+1,
 	   editor.song->numsections);
@@ -1071,7 +1071,7 @@ void gui_sectionlist_delete() {
   if(editor.section>=editor.song->numsections)
     editor.section=editor.song->numsections-1;
 
-  refresh_playseq_and_block();
+  player_refresh_playseq_and_block();
   gui_playseq_refresh();
   gui_sectionlist_refresh();
 }
@@ -1080,7 +1080,7 @@ void gui_sectionlist_previous() {
   if(editor.song->sections[editor.section]>0)
     editor.song->sections[editor.section]--;
 
-  refresh_playseq_and_block();
+  player_refresh_playseq_and_block();
   gui_playseq_refresh();
   gui_sectionlist_refresh();
 }
@@ -1089,7 +1089,7 @@ void gui_sectionlist_next() {
   if(editor.song->sections[editor.section]<editor.song->numplayseqs-1)
     editor.song->sections[editor.section]++;
 
-  refresh_playseq_and_block();
+  player_refresh_playseq_and_block();
   gui_playseq_refresh();
   gui_sectionlist_refresh();
 }
