@@ -19,6 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <glib.h>
 #include <gtk/gtk.h>
 #include "gui.h"
 #include "editor.h"
@@ -26,6 +27,9 @@
 extern struct editor editor;
 
 int main(int argc, char *argv[]) {
+#ifdef G_THREADS_IMPL_POSIX
+  if(!g_thread_supported())
+    g_thread_init(NULL);
   gtk_init(&argc, &argv);
 
   gui_create();
@@ -37,9 +41,16 @@ int main(int argc, char *argv[]) {
 
   gui_main_show();
 
+  gdk_threads_enter();
   gtk_main();
+  gdk_threads_leave();
 
   editor_close();
 
   return 0;
+#else
+  fprintf(stderr, "No POSIX threads implementation.\n");
+
+  return -1;
+#endif
 }
